@@ -1,6 +1,8 @@
 const KRAKEN_API_KEY: &str = "KRAKEN_API_KEY";
 const KRAKEN_PRIVATE_KEY: &str = "KRAKEN_PRIVATE_KEY";
 
+/// KrakenCredentials are the login credentials used by this library
+/// to authenticate requests.
 pub struct KrakenCredentials {
     api_key: String,
     private_key: String,
@@ -14,7 +16,10 @@ impl KrakenCredentials {
     }
 
     pub fn new(api_key: String, private_key: String) -> Self {
-        Self {api_key, private_key}
+        Self {
+            api_key,
+            private_key,
+        }
     }
 
     pub fn api_key(&self) -> &String {
