@@ -1,3 +1,4 @@
+pub use account_tier::AccountTier;
 pub use asset_pair::AssetPair;
 pub use client::Client;
 pub use endpoints::{
@@ -5,11 +6,13 @@ pub use endpoints::{
     SYSTEM_TIME, TICKER, TRADE_BALANCE,
 };
 pub use env::KrakenCredentials;
+
+mod account_tier;
 mod asset_pair;
 mod client;
 mod endpoints;
+mod env;
 mod payload;
 mod ratelimiter;
 mod request_builder;
 mod signature;
-mod env;
