@@ -4,9 +4,12 @@ pub use asset_pairs::{
     AssetPairsInfo, AssetPairsInput, AssetPairsResponse, SerializableAssetPairsInput,
 };
 pub use open_orders::OpenOrdersInput;
-pub use recent_spreads::{RecentSpreadsInput, RecentSpreadsResponse};
+pub use recent_spreads::{
+    RawRecentSpreadsResponse, RecentSpreadsInput, RecentSpreadsResponse, Spread,
+};
 pub use server_time::ServerTimeResponse;
 pub use system_status::SystemStatusResponse;
+pub use ticker::{RawTickerResponse, TickerInput, TickerResponse};
 pub use trade_balance::TradeBalanceInput;
 
 mod account_balance;
@@ -16,4 +19,5 @@ mod open_orders;
 mod recent_spreads;
 mod server_time;
 mod system_status;
+mod ticker;
 mod trade_balance;
